@@ -3,7 +3,7 @@ use Dancer ':syntax';
 
 use 5.008005;
 
-our $VERSION = '0.26';
+our $VERSION = '0.27';
 
 use Data::Dumper qw(Dumper);
 use Email::Valid   ();
@@ -680,7 +680,38 @@ post '/set_site_config.json' => sub {
 	return to_json { success => 1 };
 };
 
+
 post '/change_password.json' => sub {
+	my %params = _clean_params(qw(uid name new_password admin_password));
+	return render_response 'error', { 'no_uid_or_name' => 1 }  if not $params{uid} and not $params{name};
+	return render_response 'error', { 'no_new_password' => 1 } if not $params{new_password};
+	return render_response 'error', { 'no_admin_password' => 1 } if not $params{admin_password};
+
+	my $new_sha1 = sha1_base64( $params{new_password} );
+	my $admin_sha1 = sha1_base64( $params{admin_password} );
+
+	my $db = _get_db();
+	my $admin = $db->resultset('User')->find( { id => session->{userid} } );
+
+	return render_response 'error', { 'invalid_admin_password' => 1 }
+		if $admin->sha1 ne $admin_sha1;
+
+	my $user;
+	if ($params{uid}) {
+		$user = $db->resultset('User')->find( { id => $params{uid} } );
+	} else {
+		$user = $db->resultset('User')->find( { name => $params{name} } );
+	}
+
+	return render_response 'error', { 'no_user_found' => 1 } if not $user;
+
+	$user->sha1($new_sha1);
+	$user->update;
+
+	return to_json { success => 1 };
+};
+
+post '/change_my_password.json' => sub {
 	my %params = _clean_params(qw(new_password old_password));
 	return render_response 'error', { 'no_new_password' => 1 } if not $params{new_password};
 	return render_response 'error', { 'no_old_password' => 1 } if not $params{old_password};
